@@ -36,10 +36,7 @@ mod tests {
 
     #[test]
     fn test_direction() {
-        assert_eq!(
-            Direction::from_deg(90.),
-            Direction::from_deg(90. + 360.)
-        );
+        assert_eq!(Direction::from_deg(90.), Direction::from_deg(90. + 360.));
         assert_abs_diff_eq!(
             Direction::from_deg(90.).deg(),
             Direction::from_radian(PI / 2.).deg()
@@ -52,10 +49,7 @@ mod tests {
             Direction::from_deg(90.).radian(),
             Direction::from_radian(PI / 2.).radian()
         );
-        assert_eq!(
-            Direction::from_deg(-90.),
-            Direction::from_deg(-90. + 360.)
-        );
+        assert_eq!(Direction::from_deg(-90.), Direction::from_deg(-90. + 360.));
         assert_abs_diff_eq!(
             Direction::from_deg(-90.).deg(),
             Direction::from_radian(-1.0 * PI / 2.).deg()
