@@ -6,22 +6,17 @@ use std::{
     hash::{Hash, Hasher},
 };
 
-const HASH_FACTOR: f64 = 1_000_000.0;
+use crate::angle::Angle;
 
 /// Longitude in degrees, required be within the range -180.0 to 180.0
-#[derive(Into, Clone, Copy, Display, FromStr, Debug, Serialize, Deserialize)]
-#[serde(into = "f64", try_from = "f64")]
-pub struct Longitude(f64);
+#[derive(
+    Into, Clone, Copy, Display, FromStr, Debug, Serialize, Deserialize, PartialEq, Hash, Eq,
+)]
+pub struct Longitude(Angle);
 
-impl PartialEq for Longitude {
-    fn eq(&self, other: &Self) -> bool {
-        (self.0 * HASH_FACTOR) as i32 == (other.0 * HASH_FACTOR) as i32
-    }
-}
-
-impl Hash for Longitude {
-    fn hash<H: Hasher>(&self, state: &mut H) {
-        ((self.0 * HASH_FACTOR) as u32).hash(state);
+impl From<Longitude> for f64 {
+    fn from(item: Longitude) -> Self {
+        item.0.deg()
     }
 }
 
@@ -29,7 +24,7 @@ impl TryFrom<f64> for Longitude {
     type Error = Error;
     fn try_from(item: f64) -> Result<Self, Self::Error> {
         if item >= -180.0 && item <= 180.0 {
-            Ok(Self(item))
+            Ok(Self(Angle::from_deg(item)))
         } else {
             Err(format_err!("{} is not a valid longitude", item))
         }
